@@ -1,29 +1,16 @@
 import unittest
-import tempfile
-import os
 
 from pgsanity import ecpg
 
 class TestEcpg(unittest.TestCase):
-    def setUp(self):
-        self.file = tempfile.NamedTemporaryFile(delete=False, suffix=".pgc")
-
-    def tearDown(self):
-        self.file.close()
-        os.remove(self.file.name)
-
     def test_simple_success(self):
-        text = "EXEC SQL select a from b;"
-        write_out(self.file, text.encode('utf-8'))
-
-        (success, msg) = ecpg.check_syntax(self.file.name)
+        text = u"EXEC SQL select a from b;"
+        (success, msg) = ecpg.check_syntax(text)
         self.assertTrue(success)
 
     def test_simple_failure(self):
-        text = "EXEC SQL garbage select a from b;"
-        write_out(self.file, text.encode('utf-8'))
-
-        (success, msg) = ecpg.check_syntax(self.file.name)
+        text = u"EXEC SQL garbage select a from b;"
+        (success, msg) = ecpg.check_syntax(text)
         self.assertFalse(success)
         self.assertEqual('line 1: ERROR: unrecognized data type name "garbage"', msg)
 
@@ -36,7 +23,3 @@ class TestEcpg(unittest.TestCase):
         error = '/tmp/tmpLBKZo5.pgc:5: ERROR: syntax error at or near "//"'
         expected = 'line 5: ERROR: syntax error at or near "--"'
         self.assertEqual(expected, ecpg.parse_error(error))
-
-def write_out(f, text):
-    f.write(text)
-    f.flush()
